@@ -17,7 +17,7 @@ Message Id factor based on the i18n/messageid file of Zope 3.
 
 Adapted for the Placeless Translation Service by Christian Heimes
 
-$Id: MessageID.py 10622 2005-08-07 19:10:13Z batlogg $
+$Id: MessageID.py 13465 2005-10-27 17:36:11Z hannosch $
 """
 from types import BuiltinFunctionType, UnicodeType, StringType
 
@@ -30,13 +30,6 @@ from Products.PlacelessTranslationService import translate, utranslate
 from PatchStringIO import applyRequestPatch
 applyRequestPatch()
 
-try:
-    True
-except NameError:
-    True=1
-    False=0
-
-
 class MessageIDBase:
     """Message ID.
 
