@@ -1,5 +1,5 @@
 ##############################################################################
-#    Copyright (C) 2001, 2002, 2003 Lalo Martins <lalo@laranja.org>,
+#    Copyright (C) 2001-2005 Lalo Martins <lalo@laranja.org>,
 #                  Zope Corporation and Contributors
 
 #    This program is free software; you can redistribute it and/or modify
@@ -17,7 +17,7 @@
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA
 """Placeless Translation Service for providing I18n to file-based code.
 
-$Id: PlacelessTranslationService.py 10622 2005-08-07 19:10:13Z batlogg $
+$Id: PlacelessTranslationService.py 14013 2005-11-16 18:41:37Z hannosch $
 """
 
 import sys, os, re, fnmatch
@@ -47,12 +47,6 @@ from GettextMessageCatalog import ptFile
 
 PTS_IS_RTL = '_pts_is_rtl'
 
-try:
-    True
-except NameError:
-    True=1
-    False=0
-
 try:
     from pax import XML
 except:
@@ -154,6 +148,13 @@ class PTSWrapper(Base):
         service = self.load(context)
         return service.negotiate_language(context.REQUEST,domain)
 
+    security.declarePublic('isRTL')
+    def isRTL(self, context, domain):
+        service = self.load(context)
+        # Default to LtR
+        if service is None: return False
+        return service.isRTL(context.REQUEST,domain)
+
     def __repr__(self):
         """
         return a string representation
@@ -174,7 +175,7 @@ class PlacelessTranslationService(Folder):
     # -3 for alpha, -2 for beta, -1 for release candidate
     # for forked releases internal is always 99
     # use an internal of >99 to recreate the PTS at every startup (development mode)
-    _class_version = (1, 1, 3, -1)
+    _class_version = (1, 2, 5, 0)
     all_meta_types = ()
 
     manage_options = Folder.manage_options + (
